:orphan:

.. _ug-quantization_config:


=================================
quantization_config Module
=================================

ThresholdSelectionMethod
==========================
**Enum to select a method for quantization threshold selection:**

.. autoclass:: model_compression_toolkit.ThresholdSelectionMethod


|

QuantizationMethod
==========================
**Enum to select a method to use during quantization:**

.. autoclass:: model_compression_toolkit.QuantizationMethod


|



QuantizationConfig
==========================
**Class to configure the quantization process of the model:**

.. autoclass:: model_compression_toolkit.QuantizationConfig

